==> 1.0.0.zip: vancedmanager/READMEME.md <==
![Signed APK Builder](https://github.com/X1nto/VancedInstaller/workflows/Signed%20APK%20Builder/badge.svg?branch=master)

# Prelude
Hi, my name is Steve Cock, I'm the main developer for the upcoming Vanced Manager. When xfileFIN first published Vanced 15.05.54, people were upset because new Vanced used split apk files. The reason for that was pretty simple:  
1) YouTube itself does that  
2) Split apk files reduce the size of the downloaded file itself  

No one really thought there would be problems with this format, because installation was pretty simple, at least that's what xfile thought...  
## Problems with .apks format
Main problems with new format were either with device CPU architecture or MemeUI shit with MiUI optimisations. We wrote instructions for VancedHelper but no one used it for troubleshooting. Then some users complained about new format and refused to upgrade to newest version (We don't give a fuck about that) because "I dOn'T WaNT To HaVe OnE MoRE apP To insTalL VanCeD" so we decided to make an installer for Vanced  
# Vanced Manager
Ladies and gentlemen, I'm very proud to introduce the new **Vancad Manger 1.0.0™** (typo is intentional)  
Vanced Manager is an universal utility for installing/updating Vanced and MicroG. It will push notifications once the update is ready (Now that's what I call pwetty epic).  
Vanced manager comes with a slick UI ~~that was stolen from the new Magisk Manager (I'm very sorry John but I looked at your code for about 100 times).~~ Actually, while UI may look very similar to new Magisk Manager's UI, It's still very different (that's a blatant lie, I know).  

Main Menu screenshot taken from tablet
![screenshot](https://i.imgur.com/r2jiq7J.png)  
Isn't this lovely and beautiful?

## Manager (clap) Reviews (clap)

- 1337Potato: shit  
- Response: Yes  
  
- Noobbot: The app is not useful because I have YT Premium. Thank you bye  
- Response: I hope you get sucked by a di-  
  
- Vortextriangle: The app is so useful that I uninstalled it after installing Vanced  
- Response: yo that's finna woke  

## Credits
### Vanced Manager developers  
- X1nto (UI, UX, Downloader, Installer, Signature Checker, PussiSlayer69, Collector of 400 BAT, Professional Liar)
### The Vanced Team  
- xfileFIN  
![xfileFIN](https://i.imgur.com/hLdzTVq.png)
- KevinX8  
![KevinX8](https://i.imgur.com/cS9C7P8.png)
- Zanezam  
![Zanezam](https://i.imgur.com/QVcXA6q.png)
- Laura Almeida  
![Laura Almeida](https://i.imgur.com/ovVD939.png)

==> 1.3.0.zip: vancedmanager/READMEME.md <==
![Signed APK Builder](https://github.com/X1nto/VancedInstaller/workflows/Signed%20APK%20Builder/badge.svg?branch=master)

# Prelude
Hi, my name is Steve Cock, I'm the main developer for the upcoming Vanced Manager. When xfileFIN first published Vanced 15.05.54, people were upset because new Vanced used split apk files. The reason for that was pretty simple:  
1) YouTube itself does that  
2) Split apk files reduce the size of the downloaded file itself  

No one really thought there would be problems with this format, because installation was pretty simple, at least that's what xfile thought...  
## Problems with .apks format
Main problems with new format were either with device CPU architecture or MemeUI shit with MiUI optimisations. We wrote instructions for VancedHelper but no one used it for troubleshooting. Then some users complained about new format and refused to upgrade to newest version (We don't give a fuck about that) because "I dOn'T WaNT To HaVe OnE MoRE apP To insTalL VanCeD" so we decided to make an installer for Vanced  
# Vanced Manager
Ladies and gentlemen, I'm very proud to introduce the new **Vancad Manger 1.2.0™** (typo is intentional)  
Vanced Manager is an universal utility for installing/updating Vanced and MicroG. It will push notifications once the update is ready (Now that's what I call pwetty epic).  
Vanced manager comes with a slick UI ~~that was stolen from the new Magisk Manager (I'm very sorry John but I looked at your code for about 100 times).~~ Actually, while UI may look very similar to new Magisk Manager's UI, It's still very different (that's a blatant lie, I know).  

Main Menu screenshot taken from tablet
![screenshot](https://i.imgur.com/r2jiq7J.png)  
Isn't this lovely and beautiful?

## Manager (clap) Reviews (clap)

- 1337Potato: shit  
- Response: Yes  

===================
  
- Noobbot: The app is not useful because I have YT Premium. Thank you bye  
- Response: I hope you get sucked by a di- 

=================== 
  
- Vortextriangle: The app is so useful that I uninstalled it after installing Vanced  
- Response: yo that's finna woke  

## Credits
### Vanced Manager developers  
- X1nto (UI, UX, Downloader, Installer, Signature Checker, PussiSlayer69, Collector of 400 BAT, A great liar)
- Koopah (Unix lord, Unmounter of /system, Code criticizer)
### The Vanced Team  
- xfileFIN  
![xfileFIN](https://i.imgur.com/hLdzTVq.png)
- KevinX8  
![KevinX8](https://i.imgur.com/cS9C7P8.png)
- Zanezam  
![Zanezam](https://i.imgur.com/QVcXA6q.png)
- Laura Almeida  
![Laura Almeida](https://i.imgur.com/ovVD939.png)

###### If someone is reading this pls help me, KevinX8 is bullying me and forces me to develop manager. please send bobs and veganas and call 911
